@@ -8,7 +8,7 @@ package Object::Pad;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Carp;
 
@@ -80,12 +80,28 @@ to store references to anonymous arrays or hashes.
       ...
    }
 
+   method NAME :attrs... {
+      ...
+   }
+
 Declares a new named method. This behaves similarly to the C<sub> keyword,
 except that within the body of the method all of the member attributes
 ("slots") are also accessible. In addition, the method body will have a
-lexical called C<$self> which contains the invant object directly; it will
+lexical called C<$self> which contains the invocant object directly; it will
 already have been shifted from the C<@_> array.
 
+A list of attributes may be supplied as for C<sub>. The most useful of these
+is C<:lvalue>, allowing easy creation of read-write accessors for slots.
+
+   class Counter {
+      has $count;
+
+      method count :lvalue { $count }
+   }
+
+   my $c = Counter->new;
+   $c->count++;
+
 =cut
 
 sub import
@@ -109,6 +125,46 @@ sub import_into
    croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
 }
 
+=head1 TODO
+
+=over 4
+
+=item *
+
+Setting default package using C<class Name;> statement without block.
+
+=item *
+
+Subclassing. Single-inheritence is easier than multi so maybe that first.
+
+=item *
+
+Sub signatures
+
+=item *
+
+Detect and croak on attempts to invoke C<method> subs on non-instances.
+
+=item *
+
+Experiment with C<CvOUTSIDE> or other techniques as a way to set up the
+per-method pad, and consider if we can detect which slots are in use that way
+to improve method-enter performance.
+
+=item *
+
+Some extensions of the C<has> syntax:
+
+Default expressions
+
+   has $var = DEFAULT;
+
+A way to request generated accessors - ro or rw.
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
